summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmblobedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmblobedit.h')
-rw-r--r--kpovmodeler/pmblobedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmblobedit.h b/kpovmodeler/pmblobedit.h
index bada56da..9e389964 100644
--- a/kpovmodeler/pmblobedit.h
+++ b/kpovmodeler/pmblobedit.h
@@ -40,9 +40,9 @@ class PMBlobEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMBlobEdit with tqparent and name
*/
- PMBlobEdit( TQWidget* tqparent, const char* name = 0 );
+ PMBlobEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -40,9 +40,9 @@ class PMBlobEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMBlobEdit with tqparent and name
+ * Creates a PMBlobEdit with parent and name
*/